import { marked } from 'marked';
import type { Post } from '@blog/model/Post';
import type { PostMeta } from '@blog/model/PostMeta';
import * as yamlFront from 'yaml-front-matter';

export async function openPostMarkdownFile(filename: string): Promise<string> {
  const file = Bun.file(filename);
  return file.text();
}

export function parsePostMetadata(post: string): PostMeta {
  const parsedData = yamlFront.loadFront(post);

  return {
    title: parsedData.title,
    description: parsedData.description,
    date: new Date(parsedData.date),
    draft: parsedData?.draft || false,
    tags: parsedData.tags
  };
}

export async function readPostMarkdown(filename: string): Promise<Post> {
  const file = Bun.file(filename);
  const contents = await file.text();

  const parsedData = yamlFront.loadFront(contents);
  const parsedPost = await marked.parse(parsedData.__content);

  return {
    meta: {
      title: parsedData.title,
      slug: filename.slice(0, -3),
      description: parsedData.description,
      date: new Date(parsedData.date),
      tags: parsedData.tags,
    },
    content: parsedData.__content,
    html: parsedPost
  };
}

